Constant Field Values
Contents
software.amazon.*
-
software.amazon.awssdk.services.paymentcryptographydata.PaymentCryptographyDataAsyncClient Modifier and Type Constant Field Value public static final StringSERVICE_METADATA_ID"dataplane.payment-cryptography"public static final StringSERVICE_NAME"payment-cryptography" -
software.amazon.awssdk.services.paymentcryptographydata.PaymentCryptographyDataClient Modifier and Type Constant Field Value public static final StringSERVICE_METADATA_ID"dataplane.payment-cryptography"public static final StringSERVICE_NAME"payment-cryptography"
-
software.amazon.awssdk.services.paymentcryptographydata.internal.ServiceVersionInfo Modifier and Type Constant Field Value public static final StringVERSION"2.41.x"