Class DerivationMethodAttributes
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<DerivationMethodAttributes.Builder,DerivationMethodAttributes>
Parameters to derive the payment card specific confidentiality and integrity keys.
- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interfacestatic enum -
Method Summary
Modifier and TypeMethodDescriptionfinal AmexAttributesamex()Parameters to derive the confidentiality and integrity keys for a payment card using Amex derivation method.builder()final Emv2000Attributesemv2000()Parameters to derive the confidentiality and integrity keys for a payment card using Emv2000 derivation method.final EmvCommonAttributesParameters to derive the confidentiality and integrity keys for a payment card using Emv common derivation method.final booleanfinal booleanequalsBySdkFields(Object obj) static DerivationMethodAttributesCreate an instance of this class withamex()initialized to the given value.static DerivationMethodAttributesfromAmex(AmexAttributes amex) Create an instance of this class withamex()initialized to the given value.static DerivationMethodAttributesfromEmv2000(Consumer<Emv2000Attributes.Builder> emv2000) Create an instance of this class withemv2000()initialized to the given value.static DerivationMethodAttributesfromEmv2000(Emv2000Attributes emv2000) Create an instance of this class withemv2000()initialized to the given value.static DerivationMethodAttributesfromEmvCommon(Consumer<EmvCommonAttributes.Builder> emvCommon) Create an instance of this class withemvCommon()initialized to the given value.static DerivationMethodAttributesfromEmvCommon(EmvCommonAttributes emvCommon) Create an instance of this class withemvCommon()initialized to the given value.static DerivationMethodAttributesfromMastercard(Consumer<MasterCardAttributes.Builder> mastercard) Create an instance of this class withmastercard()initialized to the given value.static DerivationMethodAttributesfromMastercard(MasterCardAttributes mastercard) Create an instance of this class withmastercard()initialized to the given value.static DerivationMethodAttributesCreate an instance of this class withvisa()initialized to the given value.static DerivationMethodAttributesfromVisa(VisaAttributes visa) Create an instance of this class withvisa()initialized to the given value.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final MasterCardAttributesParameters to derive the confidentiality and integrity keys for a payment card using Mastercard derivation method.static Class<? extends DerivationMethodAttributes.Builder>final StringtoString()Returns a string representation of this object.type()Retrieve an enum value representing which member of this object is populated.final VisaAttributesvisa()Parameters to derive the confidentiality and integrity keys for a a payment card using Visa derivation method.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
emvCommon
Parameters to derive the confidentiality and integrity keys for a payment card using Emv common derivation method.
- Returns:
- Parameters to derive the confidentiality and integrity keys for a payment card using Emv common derivation method.
-
amex
Parameters to derive the confidentiality and integrity keys for a payment card using Amex derivation method.
- Returns:
- Parameters to derive the confidentiality and integrity keys for a payment card using Amex derivation method.
-
visa
Parameters to derive the confidentiality and integrity keys for a a payment card using Visa derivation method.
- Returns:
- Parameters to derive the confidentiality and integrity keys for a a payment card using Visa derivation method.
-
emv2000
Parameters to derive the confidentiality and integrity keys for a payment card using Emv2000 derivation method.
- Returns:
- Parameters to derive the confidentiality and integrity keys for a payment card using Emv2000 derivation method.
-
mastercard
Parameters to derive the confidentiality and integrity keys for a payment card using Mastercard derivation method.
- Returns:
- Parameters to derive the confidentiality and integrity keys for a payment card using Mastercard derivation method.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<DerivationMethodAttributes.Builder,DerivationMethodAttributes>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
fromEmvCommon
Create an instance of this class withemvCommon()initialized to the given value.Parameters to derive the confidentiality and integrity keys for a payment card using Emv common derivation method.
- Parameters:
emvCommon- Parameters to derive the confidentiality and integrity keys for a payment card using Emv common derivation method.
-
fromEmvCommon
public static DerivationMethodAttributes fromEmvCommon(Consumer<EmvCommonAttributes.Builder> emvCommon) Create an instance of this class withemvCommon()initialized to the given value.Parameters to derive the confidentiality and integrity keys for a payment card using Emv common derivation method.
- Parameters:
emvCommon- Parameters to derive the confidentiality and integrity keys for a payment card using Emv common derivation method.
-
fromAmex
Create an instance of this class withamex()initialized to the given value.Parameters to derive the confidentiality and integrity keys for a payment card using Amex derivation method.
- Parameters:
amex- Parameters to derive the confidentiality and integrity keys for a payment card using Amex derivation method.
-
fromAmex
Create an instance of this class withamex()initialized to the given value.Parameters to derive the confidentiality and integrity keys for a payment card using Amex derivation method.
- Parameters:
amex- Parameters to derive the confidentiality and integrity keys for a payment card using Amex derivation method.
-
fromVisa
Create an instance of this class withvisa()initialized to the given value.Parameters to derive the confidentiality and integrity keys for a a payment card using Visa derivation method.
- Parameters:
visa- Parameters to derive the confidentiality and integrity keys for a a payment card using Visa derivation method.
-
fromVisa
Create an instance of this class withvisa()initialized to the given value.Parameters to derive the confidentiality and integrity keys for a a payment card using Visa derivation method.
- Parameters:
visa- Parameters to derive the confidentiality and integrity keys for a a payment card using Visa derivation method.
-
fromEmv2000
Create an instance of this class withemv2000()initialized to the given value.Parameters to derive the confidentiality and integrity keys for a payment card using Emv2000 derivation method.
- Parameters:
emv2000- Parameters to derive the confidentiality and integrity keys for a payment card using Emv2000 derivation method.
-
fromEmv2000
Create an instance of this class withemv2000()initialized to the given value.Parameters to derive the confidentiality and integrity keys for a payment card using Emv2000 derivation method.
- Parameters:
emv2000- Parameters to derive the confidentiality and integrity keys for a payment card using Emv2000 derivation method.
-
fromMastercard
Create an instance of this class withmastercard()initialized to the given value.Parameters to derive the confidentiality and integrity keys for a payment card using Mastercard derivation method.
- Parameters:
mastercard- Parameters to derive the confidentiality and integrity keys for a payment card using Mastercard derivation method.
-
fromMastercard
public static DerivationMethodAttributes fromMastercard(Consumer<MasterCardAttributes.Builder> mastercard) Create an instance of this class withmastercard()initialized to the given value.Parameters to derive the confidentiality and integrity keys for a payment card using Mastercard derivation method.
- Parameters:
mastercard- Parameters to derive the confidentiality and integrity keys for a payment card using Mastercard derivation method.
-
type
Retrieve an enum value representing which member of this object is populated. When this class is returned in a service response, this will beDerivationMethodAttributes.Type.UNKNOWN_TO_SDK_VERSIONif the service returned a member that is only known to a newer SDK version. When this class is created directly in your code, this will beDerivationMethodAttributes.Type.UNKNOWN_TO_SDK_VERSIONif zero members are set, andnullif more than one member is set. -
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-