Class DynamicCardVerificationCode
java.lang.Object
software.amazon.awssdk.services.paymentcryptographydata.model.DynamicCardVerificationCode
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<DynamicCardVerificationCode.Builder,DynamicCardVerificationCode>
@Generated("software.amazon.awssdk:codegen")
public final class DynamicCardVerificationCode
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<DynamicCardVerificationCode.Builder,DynamicCardVerificationCode>
Parameters that are required to generate or verify Dynamic Card Verification Value (dCVV).
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal StringThe transaction counter value that comes from the terminal.builder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringA number that identifies and differentiates payment cards with the same Primary Account Number (PAN).static Class<? extends DynamicCardVerificationCode.Builder>final StringtoString()Returns a string representation of this object.final StringThe data on the two tracks of magnetic cards used for financial transactions.final StringA random number generated by the issuer.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
unpredictableNumber
A random number generated by the issuer.
- Returns:
- A random number generated by the issuer.
-
panSequenceNumber
A number that identifies and differentiates payment cards with the same Primary Account Number (PAN).
- Returns:
- A number that identifies and differentiates payment cards with the same Primary Account Number (PAN).
-
applicationTransactionCounter
The transaction counter value that comes from the terminal.
- Returns:
- The transaction counter value that comes from the terminal.
-
trackData
The data on the two tracks of magnetic cards used for financial transactions. This includes the cardholder name, PAN, expiration date, bank ID (BIN) and several other numbers the issuing bank uses to validate the data received.
- Returns:
- The data on the two tracks of magnetic cards used for financial transactions. This includes the cardholder name, PAN, expiration date, bank ID (BIN) and several other numbers the issuing bank uses to validate the data received.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<DynamicCardVerificationCode.Builder,DynamicCardVerificationCode>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-