A number that identifies and differentiates payment cards with the same Primary Account Number (PAN). Typically
00 is used, if no value is provided by the terminal.
Returns:
A number that identifies and differentiates payment cards with the same Primary Account Number (PAN).
Typically 00 is used, if no value is provided by the terminal.
The derivation value used to derive the ICC session key. It is typically the application transaction counter
value padded with zeros or previous ARQC value padded with zeros as per EMV version 4.3 book 2.
Returns:
The derivation value used to derive the ICC session key. It is typically the application transaction
counter value padded with zeros or previous ARQC value padded with zeros as per EMV version 4.3 book 2.
If the service returns an enum value that is not available in the current SDK version, mode will return
EmvEncryptionMode.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from
modeAsString().
If the service returns an enum value that is not available in the current SDK version, mode will return
EmvEncryptionMode.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from
modeAsString().
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be
redacted from this string using a placeholder value.