Class EncryptionDecryptionAttributes
java.lang.Object
software.amazon.awssdk.services.paymentcryptographydata.model.EncryptionDecryptionAttributes
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<EncryptionDecryptionAttributes.Builder,EncryptionDecryptionAttributes>
@Generated("software.amazon.awssdk:codegen")
public final class EncryptionDecryptionAttributes
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<EncryptionDecryptionAttributes.Builder,EncryptionDecryptionAttributes>
Parameters that are required to perform encryption and decryption operations.
- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interfacestatic enum -
Method Summary
Modifier and TypeMethodDescriptionReturns the value of the Asymmetric property for this object.builder()dukpt()Returns the value of the Dukpt property for this object.final EmvEncryptionAttributesemv()Parameters for plaintext encryption using EMV keys.final booleanfinal booleanequalsBySdkFields(Object obj) fromAsymmetric(Consumer<AsymmetricEncryptionAttributes.Builder> asymmetric) Create an instance of this class withasymmetric()initialized to the given value.fromAsymmetric(AsymmetricEncryptionAttributes asymmetric) Create an instance of this class withasymmetric()initialized to the given value.Create an instance of this class withdukpt()initialized to the given value.Create an instance of this class withdukpt()initialized to the given value.Create an instance of this class withemv()initialized to the given value.Create an instance of this class withemv()initialized to the given value.Create an instance of this class withsymmetric()initialized to the given value.fromSymmetric(SymmetricEncryptionAttributes symmetric) Create an instance of this class withsymmetric()initialized to the given value.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends EncryptionDecryptionAttributes.Builder>Parameters that are required to perform encryption and decryption using symmetric keys.final StringtoString()Returns a string representation of this object.type()Retrieve an enum value representing which member of this object is populated.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
symmetric
Parameters that are required to perform encryption and decryption using symmetric keys.
- Returns:
- Parameters that are required to perform encryption and decryption using symmetric keys.
-
asymmetric
Returns the value of the Asymmetric property for this object.- Returns:
- The value of the Asymmetric property for this object.
-
dukpt
Returns the value of the Dukpt property for this object.- Returns:
- The value of the Dukpt property for this object.
-
emv
Parameters for plaintext encryption using EMV keys.
- Returns:
- Parameters for plaintext encryption using EMV keys.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<EncryptionDecryptionAttributes.Builder,EncryptionDecryptionAttributes>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
fromSymmetric
Create an instance of this class withsymmetric()initialized to the given value.Parameters that are required to perform encryption and decryption using symmetric keys.
- Parameters:
symmetric- Parameters that are required to perform encryption and decryption using symmetric keys.
-
fromSymmetric
public static EncryptionDecryptionAttributes fromSymmetric(Consumer<SymmetricEncryptionAttributes.Builder> symmetric) Create an instance of this class withsymmetric()initialized to the given value.Parameters that are required to perform encryption and decryption using symmetric keys.
- Parameters:
symmetric- Parameters that are required to perform encryption and decryption using symmetric keys.
-
fromAsymmetric
public static EncryptionDecryptionAttributes fromAsymmetric(AsymmetricEncryptionAttributes asymmetric) Create an instance of this class withasymmetric()initialized to the given value. Sets the value of the Asymmetric property for this object.- Parameters:
asymmetric- The new value for the Asymmetric property for this object.
-
fromAsymmetric
public static EncryptionDecryptionAttributes fromAsymmetric(Consumer<AsymmetricEncryptionAttributes.Builder> asymmetric) Create an instance of this class withasymmetric()initialized to the given value. Sets the value of the Asymmetric property for this object.- Parameters:
asymmetric- The new value for the Asymmetric property for this object.
-
fromDukpt
Create an instance of this class withdukpt()initialized to the given value. Sets the value of the Dukpt property for this object.- Parameters:
dukpt- The new value for the Dukpt property for this object.
-
fromDukpt
public static EncryptionDecryptionAttributes fromDukpt(Consumer<DukptEncryptionAttributes.Builder> dukpt) Create an instance of this class withdukpt()initialized to the given value. Sets the value of the Dukpt property for this object.- Parameters:
dukpt- The new value for the Dukpt property for this object.
-
fromEmv
Create an instance of this class withemv()initialized to the given value.Parameters for plaintext encryption using EMV keys.
- Parameters:
emv- Parameters for plaintext encryption using EMV keys.
-
fromEmv
Create an instance of this class withemv()initialized to the given value.Parameters for plaintext encryption using EMV keys.
- Parameters:
emv- Parameters for plaintext encryption using EMV keys.
-
type
Retrieve an enum value representing which member of this object is populated. When this class is returned in a service response, this will beEncryptionDecryptionAttributes.Type.UNKNOWN_TO_SDK_VERSIONif the service returned a member that is only known to a newer SDK version. When this class is created directly in your code, this will beEncryptionDecryptionAttributes.Type.UNKNOWN_TO_SDK_VERSIONif zero members are set, andnullif more than one member is set. -
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-