Class GeneratePinDataRequest

    • Method Detail

      • generationKeyIdentifier

        public final String generationKeyIdentifier()

        The keyARN of the PEK that Amazon Web Services Payment Cryptography uses for pin data generation.

        Returns:
        The keyARN of the PEK that Amazon Web Services Payment Cryptography uses for pin data generation.
      • encryptionKeyIdentifier

        public final String encryptionKeyIdentifier()

        The keyARN of the PEK that Amazon Web Services Payment Cryptography uses to encrypt the PIN Block. For ECDH, it is the keyARN of the asymmetric ECC key.

        Returns:
        The keyARN of the PEK that Amazon Web Services Payment Cryptography uses to encrypt the PIN Block. For ECDH, it is the keyARN of the asymmetric ECC key.
      • generationAttributes

        public final PinGenerationAttributes generationAttributes()

        The attributes and values to use for PIN, PVV, or PIN Offset generation.

        Returns:
        The attributes and values to use for PIN, PVV, or PIN Offset generation.
      • pinDataLength

        public final Integer pinDataLength()

        The length of PIN under generation.

        Returns:
        The length of PIN under generation.
      • primaryAccountNumber

        public final String primaryAccountNumber()

        The Primary Account Number (PAN), a unique identifier for a payment credit or debit card that associates the card with a specific account holder.

        Returns:
        The Primary Account Number (PAN), a unique identifier for a payment credit or debit card that associates the card with a specific account holder.
      • pinBlockFormat

        public final PinBlockFormatForPinData pinBlockFormat()

        The PIN encoding format for pin data generation as specified in ISO 9564. Amazon Web Services Payment Cryptography supports ISO_Format_0 and ISO_Format_3.

        The ISO_Format_0 PIN block format is equivalent to the ANSI X9.8, VISA-1, and ECI-1 PIN block formats. It is similar to a VISA-4 PIN block format. It supports a PIN from 4 to 12 digits in length.

        The ISO_Format_3 PIN block format is the same as ISO_Format_0 except that the fill digits are random values from 10 to 15.

        If the service returns an enum value that is not available in the current SDK version, pinBlockFormat will return PinBlockFormatForPinData.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from pinBlockFormatAsString().

        Returns:
        The PIN encoding format for pin data generation as specified in ISO 9564. Amazon Web Services Payment Cryptography supports ISO_Format_0 and ISO_Format_3.

        The ISO_Format_0 PIN block format is equivalent to the ANSI X9.8, VISA-1, and ECI-1 PIN block formats. It is similar to a VISA-4 PIN block format. It supports a PIN from 4 to 12 digits in length.

        The ISO_Format_3 PIN block format is the same as ISO_Format_0 except that the fill digits are random values from 10 to 15.

        See Also:
        PinBlockFormatForPinData
      • pinBlockFormatAsString

        public final String pinBlockFormatAsString()

        The PIN encoding format for pin data generation as specified in ISO 9564. Amazon Web Services Payment Cryptography supports ISO_Format_0 and ISO_Format_3.

        The ISO_Format_0 PIN block format is equivalent to the ANSI X9.8, VISA-1, and ECI-1 PIN block formats. It is similar to a VISA-4 PIN block format. It supports a PIN from 4 to 12 digits in length.

        The ISO_Format_3 PIN block format is the same as ISO_Format_0 except that the fill digits are random values from 10 to 15.

        If the service returns an enum value that is not available in the current SDK version, pinBlockFormat will return PinBlockFormatForPinData.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from pinBlockFormatAsString().

        Returns:
        The PIN encoding format for pin data generation as specified in ISO 9564. Amazon Web Services Payment Cryptography supports ISO_Format_0 and ISO_Format_3.

        The ISO_Format_0 PIN block format is equivalent to the ANSI X9.8, VISA-1, and ECI-1 PIN block formats. It is similar to a VISA-4 PIN block format. It supports a PIN from 4 to 12 digits in length.

        The ISO_Format_3 PIN block format is the same as ISO_Format_0 except that the fill digits are random values from 10 to 15.

        See Also:
        PinBlockFormatForPinData
      • encryptionWrappedKey

        public final WrappedKey encryptionWrappedKey()
        Returns the value of the EncryptionWrappedKey property for this object.
        Returns:
        The value of the EncryptionWrappedKey property for this object.
      • toString

        public final String toString()
        Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
        Overrides:
        toString in class Object