All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<ReEncryptDataRequest.Builder,ReEncryptDataRequest>

@Generated("software.amazon.awssdk:codegen") public final class ReEncryptDataRequest extends PaymentCryptographyDataRequest implements ToCopyableBuilder<ReEncryptDataRequest.Builder,ReEncryptDataRequest>
  • Method Details

    • incomingKeyIdentifier

      public final String incomingKeyIdentifier()

      The keyARN of the encryption key of incoming ciphertext data.

      When a WrappedKeyBlock is provided, this value will be the identifier to the key wrapping key. Otherwise, it is the key identifier used to perform the operation.

      Returns:
      The keyARN of the encryption key of incoming ciphertext data.

      When a WrappedKeyBlock is provided, this value will be the identifier to the key wrapping key. Otherwise, it is the key identifier used to perform the operation.

    • outgoingKeyIdentifier

      public final String outgoingKeyIdentifier()

      The keyARN of the encryption key of outgoing ciphertext data after encryption by Amazon Web Services Payment Cryptography.

      Returns:
      The keyARN of the encryption key of outgoing ciphertext data after encryption by Amazon Web Services Payment Cryptography.
    • cipherText

      public final String cipherText()

      Ciphertext to be encrypted. The minimum allowed length is 16 bytes and maximum allowed length is 4096 bytes.

      Returns:
      Ciphertext to be encrypted. The minimum allowed length is 16 bytes and maximum allowed length is 4096 bytes.
    • incomingEncryptionAttributes

      public final ReEncryptionAttributes incomingEncryptionAttributes()

      The attributes and values for incoming ciphertext.

      Returns:
      The attributes and values for incoming ciphertext.
    • outgoingEncryptionAttributes

      public final ReEncryptionAttributes outgoingEncryptionAttributes()

      The attributes and values for outgoing ciphertext data after encryption by Amazon Web Services Payment Cryptography.

      Returns:
      The attributes and values for outgoing ciphertext data after encryption by Amazon Web Services Payment Cryptography.
    • incomingWrappedKey

      public final WrappedKey incomingWrappedKey()

      The WrappedKeyBlock containing the encryption key of incoming ciphertext data.

      Returns:
      The WrappedKeyBlock containing the encryption key of incoming ciphertext data.
    • outgoingWrappedKey

      public final WrappedKey outgoingWrappedKey()

      The WrappedKeyBlock containing the encryption key of outgoing ciphertext data after encryption by Amazon Web Services Payment Cryptography.

      Returns:
      The WrappedKeyBlock containing the encryption key of outgoing ciphertext data after encryption by Amazon Web Services Payment Cryptography.
    • toBuilder

      public ReEncryptDataRequest.Builder toBuilder()
      Specified by:
      toBuilder in interface ToCopyableBuilder<ReEncryptDataRequest.Builder,ReEncryptDataRequest>
      Specified by:
      toBuilder in class PaymentCryptographyDataRequest
    • builder

      public static ReEncryptDataRequest.Builder builder()
    • serializableBuilderClass

      public static Class<? extends ReEncryptDataRequest.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsRequest
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsRequest
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkRequest
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo