Nested Class Summary
Nested Classes
Method Summary
All Methods Static Methods Instance Methods Concrete Methods
final boolean
final boolean
final int
The keyARN of the CVK encryption key that Amazon Web Services Payment Cryptography uses to verify
card data.
The Primary Account Number (PAN), a unique identifier for a payment credit or debit card that associates the card
with a specific account holder.
Returns a string representation of this object.
The CVV or CSC value for use for card data verification within Amazon Web Services Payment Cryptography.
The algorithm to use for verification of card data within Amazon Web Services Payment Cryptography.
Method Details
keyIdentifier
public final String keyIdentifier ()
The keyARN of the CVK encryption key that Amazon Web Services Payment Cryptography uses to verify
card data.
Returns:
The keyARN of the CVK encryption key that Amazon Web Services Payment Cryptography uses to
verify card data.
primaryAccountNumber
public final String primaryAccountNumber ()
The Primary Account Number (PAN), a unique identifier for a payment credit or debit card that associates the card
with a specific account holder.
Returns:
The Primary Account Number (PAN), a unique identifier for a payment credit or debit card that associates
the card with a specific account holder.
verificationAttributes
The algorithm to use for verification of card data within Amazon Web Services Payment Cryptography.
Returns:
The algorithm to use for verification of card data within Amazon Web Services Payment Cryptography.
validationData
public final String validationData ()
The CVV or CSC value for use for card data verification within Amazon Web Services Payment Cryptography.
Returns:
The CVV or CSC value for use for card data verification within Amazon Web Services Payment Cryptography.
toString
public final String toString ()
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be
redacted from this string using a placeholder value.
Overrides:
toString in class Object