Uses of Enum
software.amazon.awssdk.services.paymentcryptographydata.model.SymmetricKeyAlgorithm
Packages that use SymmetricKeyAlgorithm
-
Uses of SymmetricKeyAlgorithm in software.amazon.awssdk.services.paymentcryptographydata.model
Methods in software.amazon.awssdk.services.paymentcryptographydata.model that return SymmetricKeyAlgorithmModifier and TypeMethodDescriptionfinal SymmetricKeyAlgorithmIncomingDiffieHellmanTr31KeyBlock.deriveKeyAlgorithm()The key algorithm of the derived ECDH key.final SymmetricKeyAlgorithmKekValidationRequest.deriveKeyAlgorithm()The key derivation algorithm to use for generating a KEK validation request.static SymmetricKeyAlgorithmUse this in place of valueOf to convert the raw string returned by the service into the enum value.final SymmetricKeyAlgorithmEcdhDerivationAttributes.keyAlgorithm()The key algorithm of the derived ECDH key.static SymmetricKeyAlgorithmReturns the enum constant of this type with the specified name.static SymmetricKeyAlgorithm[]SymmetricKeyAlgorithm.values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in software.amazon.awssdk.services.paymentcryptographydata.model that return types with arguments of type SymmetricKeyAlgorithmModifier and TypeMethodDescriptionstatic Set<SymmetricKeyAlgorithm>SymmetricKeyAlgorithm.knownValues()Methods in software.amazon.awssdk.services.paymentcryptographydata.model with parameters of type SymmetricKeyAlgorithmModifier and TypeMethodDescriptionIncomingDiffieHellmanTr31KeyBlock.Builder.deriveKeyAlgorithm(SymmetricKeyAlgorithm deriveKeyAlgorithm) The key algorithm of the derived ECDH key.KekValidationRequest.Builder.deriveKeyAlgorithm(SymmetricKeyAlgorithm deriveKeyAlgorithm) The key derivation algorithm to use for generating a KEK validation request.EcdhDerivationAttributes.Builder.keyAlgorithm(SymmetricKeyAlgorithm keyAlgorithm) The key algorithm of the derived ECDH key.