Class ReEncryptDataRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<ReEncryptDataRequest.Builder,ReEncryptDataRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic ReEncryptDataRequest.Builderbuilder()final StringCiphertext to be encrypted.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final ReEncryptionAttributesThe attributes and values for incoming ciphertext.final StringThekeyARNof the encryption key of incoming ciphertext data.final WrappedKeyThe WrappedKeyBlock containing the encryption key of incoming ciphertext data.final ReEncryptionAttributesThe attributes and values for outgoing ciphertext data after encryption by Amazon Web Services Payment Cryptography.final StringThekeyARNof the encryption key of outgoing ciphertext data after encryption by Amazon Web Services Payment Cryptography.final WrappedKeyThe WrappedKeyBlock containing the encryption key of outgoing ciphertext data after encryption by Amazon Web Services Payment Cryptography.static Class<? extends ReEncryptDataRequest.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
incomingKeyIdentifier
The
keyARNof the encryption key of incoming ciphertext data.When a WrappedKeyBlock is provided, this value will be the identifier to the key wrapping key. Otherwise, it is the key identifier used to perform the operation.
- Returns:
- The
keyARNof the encryption key of incoming ciphertext data.When a WrappedKeyBlock is provided, this value will be the identifier to the key wrapping key. Otherwise, it is the key identifier used to perform the operation.
-
outgoingKeyIdentifier
The
keyARNof the encryption key of outgoing ciphertext data after encryption by Amazon Web Services Payment Cryptography.- Returns:
- The
keyARNof the encryption key of outgoing ciphertext data after encryption by Amazon Web Services Payment Cryptography.
-
cipherText
Ciphertext to be encrypted. The minimum allowed length is 16 bytes and maximum allowed length is 4096 bytes.
- Returns:
- Ciphertext to be encrypted. The minimum allowed length is 16 bytes and maximum allowed length is 4096 bytes.
-
incomingEncryptionAttributes
The attributes and values for incoming ciphertext.
- Returns:
- The attributes and values for incoming ciphertext.
-
outgoingEncryptionAttributes
The attributes and values for outgoing ciphertext data after encryption by Amazon Web Services Payment Cryptography.
- Returns:
- The attributes and values for outgoing ciphertext data after encryption by Amazon Web Services Payment Cryptography.
-
incomingWrappedKey
The WrappedKeyBlock containing the encryption key of incoming ciphertext data.
- Returns:
- The WrappedKeyBlock containing the encryption key of incoming ciphertext data.
-
outgoingWrappedKey
The WrappedKeyBlock containing the encryption key of outgoing ciphertext data after encryption by Amazon Web Services Payment Cryptography.
- Returns:
- The WrappedKeyBlock containing the encryption key of outgoing ciphertext data after encryption by Amazon Web Services Payment Cryptography.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<ReEncryptDataRequest.Builder,ReEncryptDataRequest> - Specified by:
toBuilderin classPaymentCryptographyDataRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-